@@ -1,3 +1,4 @@
+from typing import Union
 import zmq
 
 from otmcm_backend.common.interfaces.zmq_channel import (
@@ -7,18 +8,17 @@ from otmcm_backend.common.interfaces.zmq_channel import (
 
 class TcpChannelConfig:
     # The port will be used for this channel
-    CONNECT_PORT:int
+    CONNECT_PORT:Union[int, None]=None
 
     def generate_channel_address(self)->str:
-        return f"tcp://{{host_address}}:{self.CONNECT_PORT}"
+        if self.CONNECT_PORT is None:
+            raise Exception("CONNECT_PORT need to be defined")
+        else:
+            return f"tcp://{{host_address}}:{self.CONNECT_PORT}"
 
 
-class DistributorMangerRequestChannelConfig(TcpChannelConfig):
-    # The port will be used for this channel
-    CONNECT_PORT:int = 5551
-    
 
-class OneHostDistributorMangerRequestChannel(DistributorMangerRequestChannelConfig):
+class OneHostDistributorMangerRequestChannel(TcpChannelConfig):
     """This class represents the DistributorMangerRequestChannel for the case
     Distributor and DistributorManager run on one host, which means, both Distributor and
     DistributorManager only need to bind their socket to the address
@@ -37,6 +37,10 @@ class OneHostDistributorMangerRequestChannel(DistributorMangerRequestChannelConf
             host_address="127.0.0.1"
         )
 
-class DistributorMangerUserScriptRequestChannelConfig(TcpChannelConfig):
+class DistributorMangerDistributorRequestChannelConfig(OneHostDistributorMangerRequestChannel):
+    # The port will be used for this channel
+    CONNECT_PORT:int = 5551
+    
+class DistributorMangerUserScriptRequestChannelConfig(OneHostDistributorMangerRequestChannel):
     # The port will be used for this channel
     CONNECT_PORT:int = 1997
\ No newline at end of file
