@@ -2,7 +2,7 @@ import zmq
 import logging
 
 from otmcm_backend.distributor_manager.models import (
-    ServerDistributorManagerRequestChannel,
+    ServerDistributorManagerDistributorRequestChannel,
     ServerDistributorMangerUserScriptRequestChannel
 )
 
@@ -23,4 +23,8 @@ class DistributorManager:
             context=self.context,
             logger_level=log_level
         )
-        self.distributor_req_channel = ServerDistributorManagerRequestChannel(context=self.context)
\ No newline at end of file
+        print("Hello")
+        self.distributor_req_channel = ServerDistributorManagerDistributorRequestChannel(
+            context=self.context,
+            log_level=log_level
+        )
\ No newline at end of file
