@@ -9,7 +9,7 @@ class DistributorManagerConfigInterface(ConfigObject):
         """
             The public address on the network of the distributor manager
             return: a string representing the address of the distributor manager on the network
-            example: tcp://localhost:1997
+            example: tcp://127.0.0.1:1997
         """
         pass
 
